@@ -20,11 +20,11 @@
     with any edition of Qt, and distribute the resulting executable,
     without including the source code for Qt in the source distribution.
 */
-#include <QtDBus>
-#include <klocale.h>
-
 #include "pluginbase.h"
 
+#include <QDBusInterface>
+#include <klocale.h>
+
 #include <kdebug.h>
 
 PluginBase::PluginBase()
