@@ -48,13 +48,15 @@
 
 #include <QLineEdit>
 #include <QApplication>
-#include <QtCore/QTimer>
+#include <QDir>
+#include <QTimer>
 #include <QMenu>
 #include <QStyle>
 #include <QPixmap>
 #include <QPainter>
 #include <QMouseEvent>
-#include <QtDBus/QtDBus>
+#include <QDBusConnection>
+#include <QDBusMessage>
 #include <QWidgetAction>
 #include <QStandardPaths>
 
