@@ -1,8 +1,10 @@
+#include "appearance.h"
+
 #include "kcmcss.h"
 
 #include <QFormLayout>
-#include <QtDBus/QDBusMessage>
-#include <QtDBus/QDBusConnection>
+#include <QDBusMessage>
+#include <QDBusConnection>
 #include <QGroupBox>
 
 #include <kcharsets.h>
@@ -20,8 +22,6 @@
 #include <QFontDatabase>
 #include <QSpinBox>
 
-#include "appearance.h"
-
 static const char *const animationValues[] = {"Enabled", "Disabled", "LoopOnce"};
 enum AnimationsType { AnimationsAlways = 0, AnimationsNever = 1, AnimationsLoopOnce = 2 };
 
