@@ -15,8 +15,8 @@
 #include <QFormLayout>
 #include <QVBoxLayout>
 #include <QPushButton>
-#include <QtDBus/QDBusMessage>
-#include <QtDBus/QDBusConnection>
+#include <QDBusMessage>
+#include <QDBusConnection>
 
 // KDE
 #include <kglobalsettings.h> // get default for DEFAULT_CHANGECURSOR
