@@ -27,7 +27,9 @@
 #include <kio/fileundomanager.h>
 #include <QDirIterator>
 #include <QMetaType>
-#include <QtDBus/QtDBus>
+#include <QDBusConnection>
+#include <QDBusMessage>
+#include <QDBusReply>
 #include <kglobal.h>
 #include <KLocalizedString>
 
@@ -204,7 +206,7 @@ void KonqClosedWindowsManager::emitNotifyRemove(
 }
 
 void KonqClosedWindowsManager::slotNotifyClosedWindowItem(
-    const QString &title, const int &numTabs, const QString &configFileName,
+    const QString &title, int numTabs, const QString &configFileName,
     const QString &configGroup, const QString &service)
 {
     if (isSenderOfSignal(service)) {
@@ -223,7 +225,7 @@ void KonqClosedWindowsManager::slotNotifyClosedWindowItem(
 }
 
 void KonqClosedWindowsManager::slotNotifyClosedWindowItem(
-    const QString &title, const int &numTabs, const QString &configFileName,
+    const QString &title, int numTabs, const QString &configFileName,
     const QString &configGroup, const QDBusMessage &msg)
 {
     slotNotifyClosedWindowItem(title, numTabs, configFileName, configGroup,
