@@ -27,8 +27,9 @@
 #include "konqview.h"
 #include "konqsettingsxt.h"
 
-#include <KLocalizedString>
 #include <KAboutData>
+#include <KCrash>
+#include <KLocalizedString>
 
 #include <config-konqueror.h>
 #include <konqueror-version.h>
@@ -204,6 +205,8 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
 
     KAboutData::setApplicationData(aboutData);
 
+    KCrash::initialize();
+
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
