@@ -18,14 +18,14 @@
  *
  */
 
-#include <QtWebEngine/QtWebEngineVersion>
 #include "webenginepart_ext.h"
+#include <QtWebEngine/QtWebEngineVersion>
 
 #include "webenginepart.h"
 #include "webengineview.h"
 #include "webenginepage.h"
 #include "settings/webenginesettings.h"
-#include <QtWebEngineWidgets/QWebEngineSettings>
+#include <QWebEngineSettings>
 
 #include <KDesktopFile>
 #include <KConfigGroup>
@@ -48,7 +48,6 @@
 #include <QPrinter>
 #include <QPrintDialog>
 #include <QPrintPreviewDialog>
-#include <QInputDialog>
 #include <QWebEngineHistory>
 #include <QMimeData>
 #define QL1S(x)     QLatin1String(x)
